==> nomachine-7.6.2-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAdministratorsManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAdministratorsManager::BEGIN{package NXAdministratorsManager;no warnings;
require NXPaths;do{"\x4e\x58\x50\x61\x74\x68\x73"->import};}package 
NXAdministratorsManager;no warnings;%isAdministrator;sub put{(my $username=shift
 (@_));if ((length ($username)==(0x0671+ 4822-0x1947))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($username=~ /:/ )){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw ((("\x76\x61\x6c\x75\x65\x20\x27".$username).
"\x27\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x63\x6f\x6e\x74\x61\x69\x6e\x20\x74\x68\x65\x20\x63\x68\x61\x72\x61\x63\x74\x65\x72\x20\x27\x3a\x27"
));}if (userExistInDb ($username)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x55\x73\x65\x72\x41\x6c\x72\x65\x61\x64\x79\x49\x6e\x44\x42"
->throw ((("\x41\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x3a\x20".
$username).
"\x20\x69\x73\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x69\x6e\x20\x74\x68\x65\x20\x4e\x58\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x20\x44\x42"
));}NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.main::urlencode ($username))."\x0a"));return ((0x05fa+ 7806-0x2477));}sub del{(my $field
=shift (@_));if ((not (defined ($field)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x66\x69\x65\x6c\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x6e\x75\x6c\x6c"
);}if ((length ($field)==(0x02f5+ 4293-0x13ba))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x66\x69\x65\x6c\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($field=~ s/^login=// )){if ((length ($field)==(0x14b0+ 1262-0x199e))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($field=~ /:/ )){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw ((("\x76\x61\x6c\x75\x65\x20\x27".$field).
"\x27\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x63\x6f\x6e\x74\x61\x69\x6e\x20\x74\x68\x65\x20\x63\x68\x61\x72\x61\x63\x74\x65\x72\x20\x27\x3a\x27"
));}}($field=NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($field));if ((not
 (userExistInDb ($field)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x66\x6f"->throw (((
"\x55\x73\x65\x72\x3a\x20".$field).
"\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x20\x69\x6e\x20\x74\x68\x65\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x20\x64\x61\x74\x61\x62\x61\x73\x65\x2e"
));}else{NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x72\x65\x6d\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.main::urlencode ($field))."\x0a"));}return;}sub list{(my (@users)=());
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);(my $login_line=NXRedis::get ());(my (@administrators)=());if ((defined (
$login_line)and (length ($login_line)!=(0x082d+ 262-0x0933)))){(@users=split ( / / ,
$login_line,(0x1611+ 3076-0x2215)));foreach my $administrator (@users){push (
@administrators,main::urldecode ($administrator));}}return (@administrators);}
sub userExistInDb{(my $username=shift (@_));($username=
NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($username));if (defined (
$isAdministrator{$username})){return ($isAdministrator{$username});}(my (
@userlist)=list ());($isAdministrator{$username}=(0x0802+ 5865-0x1eeb));foreach my $userData
 (@userlist){($userData=NXLogin::getAbsoluteNameForUsernameIfNotDisabled (
$userData));($isAdministrator{$userData}=(0x102d+ 5411-0x254f));}return (
$isAdministrator{$username});}sub userIsAdministrator{(my $user=shift (@_));if (
(defined ($user)and ($user ne ("")))){if (userExistInDb ($user)){return (
(0x06af+ 396-0x083a));}if (Common::NXCore::userIsSystemAdministrator ($user)){
return ((0x1ec5+ 1384-0x242c));}}return ((0x0c62+ 2877-0x179f));}sub 
userIsNXAdministrator{(my $user=shift (@_));if ((defined ($user)and ($user ne 
("")))){if (userExistInDb ($user)){return ((0x02b3+ 123-0x032d));}}return (
(0x138f+ 2319-0x1c9e));}sub printAdministratorList{(my $kindrequest=
"\x4e\x58\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x20\x6c\x69\x73\x74"
);NXMsg::send_response ("\x69\x43\x4d\x44\x55\x73\x65\x72\x6c\x69\x73\x74",
"\x4e\x58\x55\x73\x65\x72\x73\x4d\x61\x6e\x61\x67\x65\x72",$kindrequest);
main::nxwrite (main::nxgetSTDOUT (),
"\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x0a"
);(my (@userlist)=list ());foreach my $user_line (@userlist){(my $username=
sprintf ("\x25\x2d\x33\x32\x73",$user_line));main::nxwrite (main::nxgetSTDOUT ()
,($username."\x0a"));}main::nxwrite (main::nxgetSTDOUT (),"\x0a");return (
(0x203f+ 984-0x2417));}sub reloadAdministratorsDB{((%isAdministrator)=());}sub 
getDatabaseInString{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);(my $adminsList=NXRedis::get ());($adminsList=~ s/ /,/g );return ($adminsList)
;}sub cleanDb{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);}sub setDatabaseByString{(my $string=shift (@_));(my (@administrators)=split ( /,/ ,
$string,(0x0bed+ 3387-0x1928)));if ((scalar (@administrators)==
(0x0c39+ 1000-0x1021))){return ((0x0227+ 1423-0x07b6));}(my $redisString=
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73"
);foreach my $admin (@administrators){($redisString.=(
"\x2c\x66\x69\x65\x6c\x64\x3d".$admin));}($redisString.="\x0a");
NXRedis::sendToDb ($redisString);return ((0x0a73+ 6838-0x2529));}"\x3f\x3f\x3f";

==> nomachine-7.7.4-1-x86_64.pkg.tar.zst: NX/lib/perl/nxserver/NXAdministratorsManager.pm <==
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2021 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.a.r.l.                   #
#                                                                          #
#  All rights reserved.                                                    #
#                                                                          #
############################################################################
sub NXAdministratorsManager::BEGIN{package NXAdministratorsManager;no warnings;
require NXPaths;do{"\x4e\x58\x50\x61\x74\x68\x73"->import};}package 
NXAdministratorsManager;no warnings;%isAdministrator;sub put{(my $username=shift
 (@_));if ((length ($username)==(0x0cb0+ 6505-0x2619))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($username=~ /:/ )){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw ((("\x76\x61\x6c\x75\x65\x20\x27".$username).
"\x27\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x63\x6f\x6e\x74\x61\x69\x6e\x20\x74\x68\x65\x20\x63\x68\x61\x72\x61\x63\x74\x65\x72\x20\x27\x3a\x27"
));}if (userExistInDb ($username)){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x4e\x58\x55\x73\x65\x72\x3a\x3a\x55\x73\x65\x72\x41\x6c\x72\x65\x61\x64\x79\x49\x6e\x44\x42"
->throw ((("\x41\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x3a\x20".
$username).
"\x20\x69\x73\x20\x61\x6c\x72\x65\x61\x64\x79\x20\x69\x6e\x20\x74\x68\x65\x20\x4e\x58\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x20\x44\x42"
));}NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.main::urlencode ($username))."\x0a"));return ((0x1fb8+ 1323-0x24e2));}sub del{(my $field
=shift (@_));if ((not (defined ($field)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x66\x69\x65\x6c\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x6e\x75\x6c\x6c"
);}if ((length ($field)==(0x1e4c+ 1317-0x2371))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x70\x61\x72\x61\x6d\x65\x74\x65\x72\x20\x27\x66\x69\x65\x6c\x64\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($field=~ s/^login=// )){if ((length ($field)==(0x2073+ 953-0x242c))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw (
"\x76\x61\x6c\x75\x65\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x62\x65\x20\x65\x6d\x70\x74\x79"
);}if (($field=~ /:/ )){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x74\x65\x72\x6e\x61\x6c"->
throw ((("\x76\x61\x6c\x75\x65\x20\x27".$field).
"\x27\x20\x66\x6f\x72\x20\x6b\x65\x79\x20\x27\x6c\x6f\x67\x69\x6e\x27\x20\x63\x61\x6e\x6e\x6f\x74\x20\x63\x6f\x6e\x74\x61\x69\x6e\x20\x74\x68\x65\x20\x63\x68\x61\x72\x61\x63\x74\x65\x72\x20\x27\x3a\x27"
));}}($field=NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($field));if ((not
 (userExistInDb ($field)))){
"\x45\x78\x63\x65\x70\x74\x69\x6f\x6e\x3a\x3a\x49\x6e\x66\x6f"->throw (((
"\x55\x73\x65\x72\x3a\x20".$field).
"\x20\x6e\x6f\x74\x20\x66\x6f\x75\x6e\x64\x20\x69\x6e\x20\x74\x68\x65\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x20\x64\x61\x74\x61\x62\x61\x73\x65\x2e"
));}else{NXRedis::sendToDb (((
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x72\x65\x6d\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x2c\x76\x61\x6c\x75\x65\x3d"
.main::urlencode ($field))."\x0a"));}return;}sub list{(my (@users)=());
NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);(my $login_line=NXRedis::get ());(my (@administrators)=());if ((defined (
$login_line)and (length ($login_line)!=(0x0fb1+  24-0x0fc9)))){(@users=split ( / / ,
$login_line,(0x1c29+ 422-0x1dcf)));foreach my $administrator (@users){push (
@administrators,main::urldecode ($administrator));}}return (@administrators);}
sub userExistInDb{(my $username=shift (@_));($username=
NXLogin::getAbsoluteNameForUsernameIfNotDisabled ($username));if (defined (
$isAdministrator{$username})){return ($isAdministrator{$username});}(my (
@userlist)=list ());($isAdministrator{$username}=(0x0081+ 8797-0x22de));foreach my $userData
 (@userlist){($userData=NXLogin::getAbsoluteNameForUsernameIfNotDisabled (
$userData));($isAdministrator{$userData}=(0x0d45+ 527-0x0f53));}return (
$isAdministrator{$username});}sub userIsAdministrator{(my $user=shift (@_));if (
(defined ($user)and ($user ne ("")))){if (userExistInDb ($user)){return (
(0x1449+ 836-0x178c));}if (Common::NXCore::userIsSystemAdministrator ($user)){
return ((0x14cb+ 4302-0x2598));}}return ((0x1283+ 3237-0x1f28));}sub 
userIsNXAdministrator{(my $user=shift (@_));if ((defined ($user)and ($user ne 
("")))){if (userExistInDb ($user)){return ((0x0648+ 4765-0x18e4));}}return (
(0x091d+ 4619-0x1b28));}sub printAdministratorList{(my $kindrequest=
"\x4e\x58\x20\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x20\x6c\x69\x73\x74"
);NXMsg::send_response ("\x69\x43\x4d\x44\x55\x73\x65\x72\x6c\x69\x73\x74",
"\x4e\x58\x55\x73\x65\x72\x73\x4d\x61\x6e\x61\x67\x65\x72",$kindrequest);
main::nxwrite (main::nxgetSTDOUT (),
"\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x2d\x0a"
);(my (@userlist)=list ());foreach my $user_line (@userlist){(my $username=
sprintf ("\x25\x2d\x33\x32\x73",$user_line));main::nxwrite (main::nxgetSTDOUT ()
,($username."\x0a"));}main::nxwrite (main::nxgetSTDOUT (),"\x0a");return (
(0x0348+ 7842-0x21ea));}sub reloadAdministratorsDB{((%isAdministrator)=());}sub 
getDatabaseInString{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x6d\x65\x6d\x62\x65\x72\x73\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);(my $adminsList=NXRedis::get ());($adminsList=~ s/ /,/g );return ($adminsList)
;}sub cleanDb{NXRedis::sendToDb (
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x64\x65\x6c\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73\x0a"
);}sub setDatabaseByString{(my $string=shift (@_));(my (@administrators)=split ( /,/ ,
$string,(0x1224+ 1188-0x16c8)));if ((scalar (@administrators)==
(0x223d+ 479-0x241c))){return ((0x06d7+ 6012-0x1e53));}(my $redisString=
"\x63\x6f\x6d\x6d\x61\x6e\x64\x3d\x73\x61\x64\x64\x2c\x73\x65\x72\x76\x69\x63\x65\x3d\x64\x62\x2c\x6b\x65\x79\x3d\x61\x64\x6d\x69\x6e\x69\x73\x74\x72\x61\x74\x6f\x72\x73"
);foreach my $admin (@administrators){($redisString.=(
"\x2c\x66\x69\x65\x6c\x64\x3d".$admin));}($redisString.="\x0a");
NXRedis::sendToDb ($redisString);return ((0x0d27+ 5140-0x213b));}"\x3f\x3f\x3f";
